# ======================================================================
# Define options
# ======================================================================

set opt(chan)	Channel/WirelessChannel
set opt(prop)	Propagation/TwoRayGround
set opt(netif)	Phy/WirelessPhy
set opt(mac)	Mac/802_11
set opt(ifq)	Queue/DropTail/PriQueue
set opt(ll)		LL
set opt(ant)        Antenna/OmniAntenna
set opt(x)		870   ;# X dimension of the topography
set opt(y)		1150   ;# Y dimension of the topography
set opt(ifqlen)	50	      ;# max packet in ifq
set opt(seed)	0.0
set opt(tr)		trace.tr    ;# trace file
set opt(nam)            namtrace.nam   ;# nam trace file
set opt(adhocRouting)   AODV
set opt(nn)             51           ;# how many nodes are simulated
set opt(nm)	"scen-50-static"
#set opt(nm)	"scen-50-10"
#set opt(nm)	"scen-50-20"
set opt(stop)		30.0		;# simulation time

# =====================================================================
# Other default settings

LL set mindelay_		50us
LL set delay_			25us
LL set bandwidth_		0	;# not used

# ======================================================================
# Main Program
# ======================================================================


#
# Initialize Global Variables
#

# create simulator instance

set ns_		[new Simulator]

# set wireless channel, radio-model and topography objects

set wtopo	[new Topography]

# create trace object for ns and nam

set tracefd	[open $opt(tr) w]
set namtrace    [open $opt(nam) w]

$ns_ trace-all $tracefd
$ns_ namtrace-all-wireless $namtrace $opt(x) $opt(y)

# define topology
$wtopo load_flatgrid $opt(x) $opt(y)

#$wprop topography $wtopo

#
# Create God
#
set god_ [create-god $opt(nn)]

#
# define how node should be created
#

#global node setting

$ns_ node-config -adhocRouting $opt(adhocRouting) \
		 -llType $opt(ll) \
		 -macType $opt(mac) \
		 -ifqType $opt(ifq) \
		 -ifqLen $opt(ifqlen) \
		 -antType $opt(ant) \
		 -propInstance [new $opt(prop)] \
		 -phyType $opt(netif) \
		 -channel [new $opt(chan)] \
		 -topoInstance $wtopo \
		 -agentTrace OFF \
                 -routerTrace ON \
                 -macTrace OFF 

#
#  Create the specified number of nodes [$opt(nn)] and "attach" them
#  to the channel. 

for {set i 0} {$i < $opt(nn) } {incr i} {
	set node_($i) [$ns_ node]	
	$node_($i) random-motion 0		;# disable random motion
}


# 
# Define node movement model
#
#puts "Loading connection pattern..."
#source $opt(cp)

# 
# Define traffic model
#
puts "Loading scenario file..."
source $opt(nm)
$node_(50) set X_ 860.159448320886
$node_(50) set Y_ 605.107989080168
$node_(50) set Z_ 0.000000000000
$ns_ at 10.185754794822 "$node_(50) setdest 760.157509531538 605.646083442118 10.536984533466"


# Define node initial position in nam
set ra [$node_(19) set ragent_]
set ra1 [$node_(2) set ragent_]
set ra2 [$node_(50) set ragent_]
set ra3 [$node_(49) set ragent_]
set ra4 [$node_(15) set ragent_]
$ns_ at 1.0 "$ra1 svc-bind 13 daytime"
$ns_ at 1.0 "$ra3 svc-bind 13 daytime"
$ns_ at 4.1 "$ra4 svc-disc-port 13"
$ns_ at 4.1 "$ra svc-disc-port 13"
$ns_ at 6.1 "$ra2 svc-disc-string daytime"
$ns_ at 18.1 "$ra2 svc-disc-string daytime"

for {set i 0} {$i < $opt(nn)} {incr i} {

    # 20 defines the node size in nam, must adjust it according to your scenario
    # The function must be called after mobility model is defined
    
    $ns_ initial_node_pos $node_($i) 20
}

#
# Tell nodes when the simulation ends
#
for {set i 0} {$i < $opt(nn) } {incr i} {
    $ns_ at $opt(stop).000000001 "$node_($i) reset";
}
proc finish {} {
        global ns_ tracefd namtrace f0 f1 l0 l1
        $ns_ flush-trace
	$ns_ halt
        close $tracefd
	close $namtrace
        exit 0
}
#tell nam the simulation stop time
$ns_ at  $opt(stop)	"$ns_ nam-end-wireless $opt(stop)"

$ns_ at  $opt(stop).000000001 "puts \"NS EXITING...\" ; finish"


puts "Starting Simulation..."
$ns_ run




